@@ -171,7 +171,10 @@ test_that("hyperlink shape", {
   doc <- ph_with(x = doc, location = ph_location_type(type = "title"), value = "Un titre 2")
   doc <- on_slide(doc, 1)
   doc <- ph_hyperlink(x = doc, type = "title", href = "https://cran.r-project.org")
+  outputfile <- tempfile(fileext = ".pptx")
+  print(doc, target = outputfile)
 
+  doc <- read_pptx(outputfile)
   rel_df <- doc$slide$get_slide(1)$rel_df()
 
   expect_true( "https://cran.r-project.org" %in% rel_df$target )
@@ -206,12 +209,12 @@ test_that("img dims in pptx", {
                  value = external_img(img.file),
                  location = ph_location(left = 1, top = 1,
                                         height = 1.06, width = 1.39),
-                 use_loc_size = FALSE)
+                 use_loc_size = TRUE)
   sm <- slide_summary(doc)
 
   expect_equal(nrow(sm), 1)
-  expect_equal(sm$cx, 0.5)
-  expect_equal(sm$cy, .2)
+  expect_equal(sm$cx, 1.39, tolerance = .01)
+  expect_equal(sm$cy, 1.06, tolerance = .01)
   expect_equal(sm$offx, 1)
   expect_equal(sm$offy, 1)
 })
